pub struct LeaseHelper { /* private fields */ }Expand description
Helper for acquiring leases. Instantiate with LeaseControl::new(), and then acquire a lease with the lease() method. The lease() call will return only once the lease is satisfied.
A single LeaseHelper may be reused to create leases an arbitrary number of times.
Implementations
Sourceimpl LeaseHelper
impl LeaseHelper
Sourcepub async fn new<'a>(
topology: &'a TopologyProxy,
name: &'a str,
lease_dependencies: Vec<LeaseDependency>,
) -> Result<Arc<Self>>
pub async fn new<'a>( topology: &'a TopologyProxy, name: &'a str, lease_dependencies: Vec<LeaseDependency>, ) -> Result<Arc<Self>>
Creates a new LeaseHelper. Returns an error upon failure to register the to-be-leased power element with Power Broker.
Sourcepub async fn create_lease_and_wait_until_satisfied(
self: &Arc<Self>,
) -> Result<Lease>
pub async fn create_lease_and_wait_until_satisfied( self: &Arc<Self>, ) -> Result<Lease>
Acquires a lease, completing only once the lease is satisfied. Returns an error if the
underlying Lessor.Lease or LeaseControl.WatchStatus call fails.
pub async fn create_lease(self: &Arc<Self>) -> Result<Lease>